@@ -7,7 +7,7 @@
 # the same terms as the Perl 5 programming language system itself.
 # 
 package Dist::Zilla::Plugin::AutoPrereq;
-our $VERSION = '0.1.2';
+our $VERSION = '0.2.0';
 
 # ABSTRACT: automatically extract prereqs from your modules
 
@@ -20,6 +20,11 @@ use version;
 
 with 'Dist::Zilla::Role::FixedPrereqs';
 
+# -- attributes
+
+# skiplist - a regex
+has skip => ( is=>'ro', predicate=>'has_skip' );
+
 
 # -- public methods
 
@@ -62,6 +67,18 @@ sub prereq {
         }
     }
 
+    # remove prereqs from skiplist
+    if ( $self->has_skip && $self->skip ) {
+        my $skip = $self->skip;
+        my $re   = qr/$skip/;
+        my @deletes;
+        foreach my $k ( keys %prereqs ) {
+            push @deletes, $k if $k =~ $re;
+        }
+        delete @prereqs{ @deletes };
+    }
+
+    # we're done, return what we've found
     return \%prereqs;
 }
 
@@ -81,13 +98,12 @@ sub _prereqs_in_file {
 
     my $p = Dist::Zilla::Util::Nonpod->_new;
     $p->read_string( $file->content );
-    my $nonpod = $p->_nonpod;
+    my @lines = split /\n/, $p->_nonpod;
 
     # quick analysis: find only plain use and require
     my @use_lines =
         grep { /^(?:use|require)\s+/ }
-        split /\n/, $nonpod;
-
+        @lines;
     foreach my $line ( @use_lines ) {
         $line =~ s/;.*$//; # trim end of statement
         my (undef, $module, $version) = split /\s+/, $line;
@@ -103,6 +119,12 @@ sub _prereqs_in_file {
         }
     }
 
+    # add moose specifics
+    my @roles =
+        map { /^(?:with)\s+['"]([\w:]+)['"]/ ? ($1) : () }
+        @lines;
+    @prereqs{ @roles } = (0) x @roles;
+
     return %prereqs;
 }
 
@@ -138,7 +160,7 @@ Dist::Zilla::Plugin::AutoPrereq - automatically extract prereqs from your module
 
 =head1 VERSION
 
-version 0.1.2
+version 0.2.0
 
 =begin Pod::Coverage
 
@@ -151,19 +173,40 @@ prereq
 In your F<dist.ini>:
 
     [AutoPrereq]
+    skip = ^Foo|Bar$
 
 =head1 DESCRIPTION
 
 This plugin will extract loosely your distribution prerequisites from
 your files.
 
-The extraction may not be perfect, since it will only find the plain
-lines beginning with C<use> or C<require> in your perl modules and
-scripts. It will trim the following pragamata: C<strict>, C<warnings>
-and C<lib>. It will also trim the modules under your dist namespace (eg:
-for C<Dist-Zilla>, it will trim all C<Dist::Zilla::*> prereqs found.
+The extraction may not be perfect, since it will only find the
+following prereqs:
 
-The module does not accept any option (yet).
+=over 4
+
+=item * plain lines beginning with C<use> or C<require> in your perl
+modules and scripts.
+
+=item * L<Moose> roles included with the C<with> keyword.
+
+=back 
+
+If some prereqs are not found, you can still add them manually with the
+L<Dist::Zilla::Plugin::Prereq> plugin.
+
+It will trim the following pragamata: C<strict>, C<warnings> and C<lib>.
+It will also trim the modules under your dist namespace (eg: for
+C<Dist-Zilla>, it will trim all C<Dist::Zilla::*> prereqs found.
+
+The module accept the following options:
+
+=over 4
+
+=item * skip: a regex that will remove any matching modules found
+from prereqs.
+
+=back 
 
 =head1 BUGS
 
